@@ -36,6 +36,7 @@ static const PkEnumMatch enum_info_icon_name[] = {
 	{PK_INFO_ENUM_LOW,			"pk-update-low"},
 	{PK_INFO_ENUM_NORMAL,			"pk-update-normal"},
 	{PK_INFO_ENUM_IMPORTANT,		"pk-update-high"},
+	{PK_INFO_ENUM_CRITICAL,			"pk-update-security"},
 	{PK_INFO_ENUM_SECURITY,			"pk-update-security"},
 	{PK_INFO_ENUM_BUGFIX,			"pk-update-bugfix"},
 	{PK_INFO_ENUM_ENHANCEMENT,		"pk-update-enhancement"},
@@ -147,17 +148,17 @@ static const PkEnumMatch enum_role_icon_name[] = {
 static const PkEnumMatch enum_group_icon_name[] = {
 	{PK_GROUP_ENUM_UNKNOWN,			"help-browser"},	/* fall though value */
 	{PK_GROUP_ENUM_ACCESSIBILITY,		"preferences-desktop-accessibility"},
-	{PK_GROUP_ENUM_ACCESSORIES,		"applications-accessories"},
+	{PK_GROUP_ENUM_ACCESSORIES,		"applications-utilities"},
 	{PK_GROUP_ENUM_ADMIN_TOOLS,		"system-lock-screen"},
 	{PK_GROUP_ENUM_COLLECTIONS,		"pk-collection-installed"},
-	{PK_GROUP_ENUM_COMMUNICATION,		"folder-remote"},
+	{PK_GROUP_ENUM_COMMUNICATION,		"network-workgroup"},
 	{PK_GROUP_ENUM_DESKTOP_GNOME,		"pk-desktop-gnome"},
 	{PK_GROUP_ENUM_DESKTOP_KDE,		"pk-desktop-kde"},
-	{PK_GROUP_ENUM_DESKTOP_OTHER,		"user-desktop"},
+	{PK_GROUP_ENUM_DESKTOP_OTHER,		"preferences-desktop-wallpaper"},
 	{PK_GROUP_ENUM_DESKTOP_XFCE,		"pk-desktop-xfce"},
-	{PK_GROUP_ENUM_DOCUMENTATION,		"x-office-address-book"},
+	{PK_GROUP_ENUM_DOCUMENTATION,		"system-help"},
 	{PK_GROUP_ENUM_EDUCATION,		"utilities-system-monitor"},
-	{PK_GROUP_ENUM_ELECTRONICS,		"video-display"},
+	{PK_GROUP_ENUM_ELECTRONICS,		"applications-engineering"},
 	{PK_GROUP_ENUM_FONTS,			"preferences-desktop-font"},
 	{PK_GROUP_ENUM_GAMES,			"applications-games"},
 	{PK_GROUP_ENUM_GRAPHICS,		"applications-graphics"},
@@ -172,8 +173,8 @@ static const PkEnumMatch enum_group_icon_name[] = {
 	{PK_GROUP_ENUM_POWER_MANAGEMENT,	"battery"},
 	{PK_GROUP_ENUM_PROGRAMMING,		"applications-development"},
 	{PK_GROUP_ENUM_PUBLISHING,		"accessories-dictionary"},
-	{PK_GROUP_ENUM_REPOS,			"system-file-manager"},
-	{PK_GROUP_ENUM_SCIENCE,			"application-certificate"},
+	{PK_GROUP_ENUM_REPOS,			"x-package-repository"},
+	{PK_GROUP_ENUM_SCIENCE,			"applications-science"},
 	{PK_GROUP_ENUM_SECURITY,		"network-wireless-encrypted"},
 	{PK_GROUP_ENUM_SERVERS,			"network-server"},
 	{PK_GROUP_ENUM_SYSTEM,			"applications-system"},
@@ -1408,8 +1409,8 @@ const gchar *
 gpk_info_status_enum_to_string (GpkInfoStatusEnum info)
 {
 	if ((PkInfoEnum)info >= PK_INFO_ENUM_LAST)
-		return gpk_info_enum_to_localised_past (info - PK_INFO_ENUM_LAST);
-	return gpk_info_enum_to_localised_present (info);
+		return gpk_info_enum_to_localised_past ((PkInfoEnum) info - PK_INFO_ENUM_LAST);
+	return gpk_info_enum_to_localised_present ((PkInfoEnum) info);
 }
 
 const gchar *
@@ -1427,5 +1428,5 @@ gpk_info_status_enum_to_icon_name (GpkInfoStatusEnum info)
 		return gpk_info_enum_to_icon_name (info - PK_INFO_ENUM_LAST);
 
 	/* regular PkInfoEnum */
-	return gpk_info_enum_to_icon_name (info);
+	return gpk_info_enum_to_icon_name ((PkInfoEnum) info);
 }
