@@ -91,7 +91,7 @@ enum {
 	GPK_UPDATES_COLUMN_LAST
 };
 
-static gboolean gpk_update_viewer_get_new_update_array (void);
+static void gpk_update_viewer_get_new_update_array (void);
 
 static gboolean
 _g_strzero (const gchar *text)
@@ -255,6 +255,17 @@ gpk_update_viewer_check_restart (void)
 			gpk_update_viewer_error_dialog (_("Could not restart"), NULL, error->message);
 		}
 #endif
+	} else if (restart_update == PK_RESTART_ENUM_SESSION) {
+		g_autoptr(GDBusConnection) bus = NULL;
+		bus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+		g_dbus_connection_call (bus,
+					"org.gnome.SessionManager",
+					"/org/gnome/SessionManager",
+					"org.gnome.SessionManager",
+					"Logout",
+					g_variant_new ("(u)", 0),
+					NULL, G_DBUS_CALL_FLAGS_NONE, G_MAXINT,
+					NULL, NULL, NULL);
 	}
 	return ret;
 }
@@ -431,14 +442,8 @@ gpk_update_viewer_update_packages_cb (PkTask *_task, GAsyncResult *res, gpointer
 		gpk_update_viewer_check_restart ();
 		gpk_update_viewer_quit ();
 		goto out;
-	} else {
-		goto out;
 	}
 
-	/* hide close button */
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_quit"));
-	gtk_widget_hide (widget);
-
 	/* show a new title */
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "label_header_title"));
 	/* TRANSLATORS: completed all updates */
@@ -517,7 +522,7 @@ gpk_update_viewer_compare_refs (GtkTreeRowReference *a, GtkTreeRowReference *b)
 }
 
 static gboolean
-gpk_update_viewer_pulse_active_rows (void)
+gpk_update_viewer_pulse_active_rows (gpointer user_data)
 {
 	GSList *l;
 	GtkTreeRowReference *ref;
@@ -1214,10 +1219,6 @@ gpk_update_viewer_modal_error_with_timeout (const gchar *title, const gchar *mes
 	GtkWidget *widget;
 	g_autofree gchar *text = NULL;
 
-	/* hide close button */
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_quit"));
-	gtk_widget_hide (widget);
-
 	/* show a new title */
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "label_header_title"));
 	/* TRANSLATORS: there are no updates */
@@ -1472,7 +1473,7 @@ gpk_update_viewer_treeview_query_tooltip_cb (GtkWidget *widget, gint x, gint y,
 			ret = FALSE;
 			break;
 		}
-		text = gpk_info_status_enum_to_string (info);
+		text = gpk_info_status_enum_to_string ((GpkInfoStatusEnum) info);
 		break;
 	default:
 		/* ignore */
@@ -1628,20 +1629,19 @@ static gchar *
 gpk_update_viewer_iso8601_format_locale_date (const gchar *iso_date)
 {
 	g_autoptr(GDateTime) dt = NULL;
-	GTimeVal timeval;
 
 	/* not valid */
 	if (iso_date == NULL || iso_date[0] == '\0')
 		return NULL;
 
 	/* parse ISO8601 date */
-	if (!g_time_val_from_iso8601 (iso_date, &timeval)) {
+	dt = g_date_time_new_from_iso8601 (iso_date, NULL);
+	if (dt == NULL) {
 		g_warning ("failed to parse %s, falling back to ISO8601", iso_date);
 		return g_strdup (iso_date);
 	}
 
 	/* convert to a date object */
-	dt = g_date_time_new_from_timeval_utc (&timeval);
 	return g_date_time_format (dt, "%x");
 }
 
@@ -1796,8 +1796,12 @@ gpk_update_viewer_populate_details (PkUpdateDetail *item)
 	/* only show changelog if we didn't have any update text */
 	if (!has_update_text && !_g_strzero (changelog)) {
 		if (!_g_strzero (changelog)) {
+			g_autofree gchar *changelog_escaped = g_markup_escape_text (changelog, -1);
+
 			/* TRANSLATORS: this is a ChangeLog */
-			line2 = g_strdup_printf ("%s\n%s\n", _("The developer logs will be shown as no description is available for this update:"), changelog);
+			line2 = g_strdup_printf ("%s\n\n<tt>%s</tt>",
+						 _("The developer logs will be shown as no description is available for this update:"),
+						 changelog_escaped);
 			gtk_text_buffer_insert_markup (text_buffer, &iter, line2, -1);
 			g_free (line2);
 		}
@@ -2202,9 +2206,7 @@ gpk_update_viewer_detail_popup_menu_create (GtkWidget *treeview, GdkEventButton
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
 	gtk_widget_show_all (menu);
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
-			(event != NULL) ? event->button : 0,
-			gdk_event_get_time((GdkEvent*)event));
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), (GdkEvent*) event);
 }
 
 static gboolean
@@ -2395,10 +2397,9 @@ gpk_update_viewer_get_updates_cb (PkClient *client, GAsyncResult *res, gpointer
 	gpk_update_viewer_reconsider_info ();
 }
 
-static gboolean
+static void
 gpk_update_viewer_get_new_update_array (void)
 {
-	gboolean ret;
 	GtkWidget *widget;
 	g_autofree gchar *text = NULL;
 	PkBitfield filter = PK_FILTER_ENUM_NONE;
@@ -2412,18 +2413,10 @@ gpk_update_viewer_get_new_update_array (void)
 	text = g_strdup_printf ("<big><b>%s</b></big>", _("Checking for updates…"));
 	gtk_label_set_label (GTK_LABEL(widget), text);
 
-	/* only show newest updates? */
-	ret = g_settings_get_boolean (settings, GPK_SETTINGS_ONLY_NEWEST);
-	if (ret) {
-		g_debug ("only showing newest updates");
-		filter = pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST, -1);
-	}
-
 	/* get new array */
 	pk_client_get_updates_async (PK_CLIENT(task), filter, cancellable,
 				     (PkProgressCallback) gpk_update_viewer_progress_cb, NULL,
 				     (GAsyncReadyCallback) gpk_update_viewer_get_updates_cb, NULL);
-	return ret;
 }
 
 /**
@@ -2443,7 +2436,7 @@ gpk_update_viewer_textview_follow_link (GtkWidget *text_view, GtkTextIter *iter)
 		GtkTextTag *tag = tagp->data;
 		const gchar *href = (const gchar *) (g_object_get_data (G_OBJECT (tag), "href"));
 		if (href != NULL)
-			gtk_show_uri (NULL, href, GDK_CURRENT_TIME, NULL);
+			gtk_show_uri_on_window (NULL, href, GDK_CURRENT_TIME, NULL);
 	}
 
 	if (tags != NULL)
@@ -2896,7 +2889,7 @@ gpk_update_viewer_application_startup_cb (GtkApplication *_application, gpointer
 	gtk_widget_show (label);
 
 	/* pack infobars into main UI */
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "vbox1"));
+	widget = GTK_WIDGET(gtk_builder_get_object (builder, "vbox2"));
 	gtk_box_pack_start (GTK_BOX(widget), info_mobile, FALSE, FALSE, 3);
 	gtk_box_reorder_child (GTK_BOX(widget), info_mobile, 1);
 	gtk_box_pack_start (GTK_BOX(widget), info_updates, FALSE, FALSE, 3);
@@ -2944,6 +2937,8 @@ main (int argc, char *argv[])
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   PKGDATADIR G_DIR_SEPARATOR_S "icons");
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+					   "/usr/share/gnome-packagekit/icons");
 
 	/* TRANSLATORS: title to pass to the user if there are not enough privs */
 	ret = gpk_check_privileged_user (_("Package Updater"), TRUE);
